@@ -128,9 +128,11 @@
           character(len=256)        ::  ps_file_spec   ! PS file spec
           integer                   ::  z          ! Atomic number
           type(ground_state_t)      ::  ground_state
+          type(ground_state_t)      ::  ground_state_tables
           type(pseudopotential_t)   ::  pseudopotential
           type(psml_t)              ::  psml_handle
           logical                   ::  has_psml_ps
+          integer                   ::  nsemic_shells(0:3)
           integer                   ::  lmxo       ! Max l for basis
           integer                   ::  lmxkb      ! Max l for KB projs
           integer                   ::  lmxdftupj  ! Max l for DFT+U projs
@@ -144,6 +146,7 @@
           logical                   ::  floating   
           logical                   ::  bessel
           logical                   ::  synthetic
+          logical                   ::  custom_valence_config
           character(len=20)         ::  basis_type
           character(len=20)         ::  basis_size
           logical                   ::  semic      ! 
