@@ -20,7 +20,7 @@
 no_version='NO_VERSION_LABEL_AVAILABLE'
 
 # Default SIESTA version (in case everything else fails).
-archived_commit='unreleased 3852ac6d4 (2024-06-25)'
+archived_commit='unreleased ae1d18995 (2024-12-11)'
 case "${archived_commit}" in
     *Format*)
         default_version="${no_version}"
@@ -54,7 +54,8 @@ elif [ "$in_git_dir" ] &&
       # Only follow first parents (required given our recurring merges).
       # Only consider regular (v[0-9]*, [0-9].[0-9]*) and MaX tags,
       # irrespective of whether they are annotated or not.
-      Vnew=$(git describe --tags --first-parent --abbrev=9 \
+      Vnew=$(git describe --always \
+              --tags --first-parent --abbrev=9 \
               --match "v[0-9]*" \
               --match "[0-9].[0-9]*" \
               --match "MaX-*" \
@@ -62,7 +63,7 @@ elif [ "$in_git_dir" ] &&
       case "${Vnew}" in
           *${LF}*) (exit 1)
               ;;
-          v[0-9]*|[0-9].[0-9]*|MaX-*)
+          *)
               # Nowadays there are simpler ways of accomplishing this, but
               # one has to be careful with old versions of git, see, e.g.,
               # https://stackoverflow.com/questions/16035240 .
