@@ -20,6 +20,7 @@ C Compute the wave functions at the points of a plane or a 3D grid
 C in real space
 C     Coded by P. Ordejon, from Junquera's rhoofr. July 2003
 !     Extended to NC spin by Alberto Garcia, 2019      
+C Modified by A. Alcaraz to print out cube files with atoms, September 2024
 C **********************************************************************
 
       use precision
@@ -759,7 +760,13 @@ C End y and z loops
        integer, intent(in) :: lun
        character(len=*), intent(in) :: fname
        ! rest by host association
-      
+         if(NAINCELL.eq.0) then
+            write(*,*) 'A fake atom was place at the origin to avoid '
+            write(*,*) 'visualization errors with the cube file.'
+            NAINCELL = 1
+            IZA(1) = 99
+            XAINCELL(:,1) = 0.0
+         endif
             WRITE(LUN,*) FNAME
             WRITE(LUN,*) FNAME
             WRITE(LUN,'(i5,4f12.6)') NAINCELL, XMIN, YMIN, ZMIN
