@@ -132,7 +132,7 @@ CONTAINS
        ! we can successfully read 4 integers
        version = 0
     else
-       backspace(iu)
+       rewind(iu)
        read(iu,iostat=err) version
     end if
 
